//+------------------------------------------------------------------+
//|                                                     Master01.mq5 |
//|                        Copyright 2010, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2010, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\Signal\SignalAC.mqh>
#include <Expert\Signal\SignalEnvelopes.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingFixedPips.mqh>
//--- available money management
#include <Expert\Money\MoneyNone.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string             Expert_Title                  ="Master01"; // Document name
int                      Expert_MagicNumber            =16950;      // 
bool                     Expert_EveryTick              =false;      // 
//--- inputs for main signal
input int                Signal_ThresholdOpen          =10;         // Signal threshold value to open [0...100]
input int                Signal_ThresholdClose         =20;         // Signal threshold value to close [0...100]
input double             Signal_PriceLevel             =0.0;        // Price level to execute a deal
input double             Signal_StopLevel              =500.0;       // Stop Loss level (in points)
input double             Signal_TakeLevel              =100.0;       // Take Profit level (in points)
input int                Signal_Expiration             =0;          // Expiration of pending orders (in bars)
//--- inputs for trailing
input int                Trailing_FixedPips_StopLevel=50;         // Stop Loss level (in points)
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert_EG;
CExpert ExtExpert_NZ;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- Initializing expert
//===================================================================================

   if(!ExtExpert_EG.Init("NZDUSD",PERIOD_M10,Expert_EveryTick,Expert_MagicNumber))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing expert");
      ExtExpert_EG.Deinit();
      return(-1);
     }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating signal");
      ExtExpert_EG.Deinit();
      return(-2);
     }
//---
   ExtExpert_EG.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalAC
   CSignalAC *filter0=new CSignalAC;
   if(filter0==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter0");
      ExtExpert_EG.Deinit();
      return(-3);
     }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.Period(PERIOD_D1);
   filter0.Weight(0.3);
//--- Creating filter CSignalEnvelopes
   CSignalEnvelopes *filter1=new CSignalEnvelopes;
   if(filter1==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter1");
      ExtExpert_EG.Deinit();
      return(-4);
     }
   signal.AddFilter(filter1);
//--- Set filter parameters
   filter1.Period(PERIOD_D1);
   filter1.PeriodMA(34);
   filter1.Method(MODE_EMA);
   filter1.Applied(PRICE_OPEN);
   filter1.Deviation(3.0);
   filter1.Weight(0.3);
//--- Creating filter CSignalAC
   CSignalAC *filter2=new CSignalAC;
   if(filter2==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter2");
      ExtExpert_EG.Deinit();
      return(-5);
     }
   signal.AddFilter(filter2);
//--- Set filter parameters
   filter2.Period(PERIOD_H4);
   filter2.Weight(0.3);
//--- Creating filter CSignalEnvelopes
   CSignalEnvelopes *filter3=new CSignalEnvelopes;
   if(filter3==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter3");
      ExtExpert_EG.Deinit();
      return(-6);
     }
   signal.AddFilter(filter3);
//--- Set filter parameters
   filter3.Period(PERIOD_H4);
   filter3.PeriodMA(55);
   filter3.Method(MODE_EMA);
   filter3.Applied(PRICE_OPEN);
   filter3.Deviation(2.0);
   filter3.Weight(0.3);
//--- Creating filter CSignalAC
   CSignalAC *filter4=new CSignalAC;
   if(filter4==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter4");
      ExtExpert_EG.Deinit();
      return(-7);
     }
   signal.AddFilter(filter4);
//--- Set filter parameters
   filter4.Period(PERIOD_M10);
   filter4.Weight(0.3);
//--- Creating filter CSignalEnvelopes
   CSignalEnvelopes *filter5=new CSignalEnvelopes;
   if(filter5==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter5");
      ExtExpert_EG.Deinit();
      return(-8);
     }
   signal.AddFilter(filter5);
//--- Set filter parameters
   filter5.Period(PERIOD_M10);
   filter5.PeriodMA(100);
   filter5.Method(MODE_EMA);
   filter5.Applied(PRICE_OPEN);
   filter5.Deviation(0.3);
   filter5.Weight(0.3);
//--- Creation of trailing object
   CTrailingFixedPips *trailing=new CTrailingFixedPips;
   if(trailing==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating trailing");
      ExtExpert_EG.Deinit();
      return(-9);
     }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert_EG.InitTrailing(trailing))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing trailing");
      ExtExpert_EG.Deinit();
      return(-10);
     }
//--- Set trailing parameters
   trailing.StopLevel(Trailing_FixedPips_StopLevel);
   trailing.ProfitLevel(100);
//--- Creation of money object
   CMoneyNone *money=new CMoneyNone;
   if(money==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating money");
      ExtExpert_EG.Deinit();
      return(-11);
     }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert_EG.InitMoney(money))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing money");
      ExtExpert_EG.Deinit();
      return(-12);
     }
//--- Set money parameters
//--- Check all trading objects parameters
   if(!ExtExpert_EG.ValidationSettings())
     {
      //--- failed
      ExtExpert_EG.Deinit();
      return(-13);
     }
//--- Tuning of all necessary indicators
   if(!ExtExpert_EG.InitIndicators())
     {
      //--- failed
      printf(__FUNCTION__+": error initializing indicators");
      ExtExpert_EG.Deinit();
      return(-14);
     }
     
//=================================================================     
     
//--- Initializing expert
   if(!ExtExpert_NZ.Init("EURUSD",PERIOD_M10,Expert_EveryTick,Expert_MagicNumber+1))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing expert");
      ExtExpert_NZ.Deinit();
      return(-1);
     }
//--- Creating signal
   CExpertSignal *signal2=new CExpertSignal;
   if(signal2==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating signal");
      ExtExpert_NZ.Deinit();
      return(-2);
     }
//---
   ExtExpert_NZ.InitSignal(signal2);
   signal2.ThresholdOpen(Signal_ThresholdOpen);
   signal2.ThresholdClose(Signal_ThresholdClose);
   signal2.PriceLevel(Signal_PriceLevel);
   signal2.StopLevel(Signal_StopLevel);
   signal2.TakeLevel(Signal_TakeLevel);
   signal2.Expiration(Signal_Expiration);
//--- Creating filter CSignalAC
   CSignalAC *filter00=new CSignalAC;
   if(filter00==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter0");
      ExtExpert_NZ.Deinit();
      return(-3);
     }
   signal2.AddFilter(filter00);
//--- Set filter parameters
   filter00.Period(PERIOD_D1);
   filter00.Weight(0.3);
//--- Creating filter CSignalEnvelopes
   CSignalEnvelopes *filter11=new CSignalEnvelopes;
   if(filter11==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter1");
      ExtExpert_NZ.Deinit();
      return(-4);
     }
   signal2.AddFilter(filter11);
//--- Set filter parameters
   filter11.Period(PERIOD_D1);
   filter11.PeriodMA(34);
   filter11.Method(MODE_EMA);
   filter11.Applied(PRICE_OPEN);
   filter11.Deviation(3.0);
   filter11.Weight(0.3);
//--- Creating filter CSignalAC
   CSignalAC *filter22=new CSignalAC;
   if(filter22==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter2");
      ExtExpert_NZ.Deinit();
      return(-5);
     }
   signal2.AddFilter(filter22);
//--- Set filter parameters
   filter22.Period(PERIOD_H4);
   filter22.Weight(0.3);
//--- Creating filter CSignalEnvelopes
   CSignalEnvelopes *filter33=new CSignalEnvelopes;
   if(filter33==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter3");
      ExtExpert_NZ.Deinit();
      return(-6);
     }
   signal2.AddFilter(filter33);
//--- Set filter parameters
   filter33.Period(PERIOD_H4);
   filter33.PeriodMA(55);
   filter33.Method(MODE_EMA);
   filter33.Applied(PRICE_OPEN);
   filter33.Deviation(2.0);
   filter33.Weight(0.3);
//--- Creating filter CSignalAC
   CSignalAC *filter44=new CSignalAC;
   if(filter44==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter4");
      ExtExpert_NZ.Deinit();
      return(-7);
     }
   signal2.AddFilter(filter44);
//--- Set filter parameters
   filter44.Period(PERIOD_M10);
   filter44.Weight(0.3);
//--- Creating filter CSignalEnvelopes
   CSignalEnvelopes *filter55=new CSignalEnvelopes;
   if(filter55==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter5");
      ExtExpert_NZ.Deinit();
      return(-8);
     }
   signal2.AddFilter(filter55);
//--- Set filter parameters
   filter55.Period(PERIOD_M10);
   filter55.PeriodMA(100);
   filter55.Method(MODE_EMA);
   filter55.Applied(PRICE_OPEN);
   filter55.Deviation(0.3);
   filter55.Weight(0.3);
//--- Creation of trailing object
   CTrailingFixedPips *trailing1=new CTrailingFixedPips;
   if(trailing1==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating trailing");
      ExtExpert_NZ.Deinit();
      return(-9);
     }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert_NZ.InitTrailing(trailing1))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing trailing");
      ExtExpert_NZ.Deinit();
      return(-10);
     }
//--- Set trailing parameters
   trailing1.StopLevel(Trailing_FixedPips_StopLevel);
   trailing1.ProfitLevel(100);
//--- Creation of money object
   CMoneyNone *money1=new CMoneyNone;
   if(money1==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating money");
      ExtExpert_NZ.Deinit();
      return(-11);
     }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert_NZ.InitMoney(money1))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing money");
      ExtExpert_NZ.Deinit();
      return(-12);
     }
//--- Set money parameters
//--- Check all trading objects parameters
   if(!ExtExpert_NZ.ValidationSettings())
     {
      //--- failed
      ExtExpert_NZ.Deinit();
      return(-13);
     }
//--- Tuning of all necessary indicators
   if(!ExtExpert_NZ.InitIndicators())
     {
      //--- failed
      printf(__FUNCTION__+": error initializing indicators");
      ExtExpert_NZ.Deinit();
      return(-14);
     }     
//=================================================================     
//--- ok
   return(0);
  }
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   ExtExpert_EG.Deinit();
   ExtExpert_NZ.Deinit();
  }
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
  {
   ExtExpert_EG.OnTick();
   ExtExpert_NZ.OnTick();
  }
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
  {
   ExtExpert_EG.OnTrade();
   ExtExpert_NZ.OnTrade();
  }
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
  {
   ExtExpert_NZ.OnTimer();
   ExtExpert_EG.OnTimer();
  }
//+------------------------------------------------------------------+
